==> autoboto-0.0.3.tar.gz: autoboto-0.0.3/autoboto/services/cloudhsmv2/client.py <==
import datetime
import typing
import boto3
import autoboto
from . import shapes


class Client:
    def __init__(self, *args, **kwargs):
        self._boto_client = boto3.client("cloudhsmv2", *args, **kwargs)

    def copy_backup_to_region(
        self,
        _request: shapes.CopyBackupToRegionRequest = None,
        *,
        destination_region: str,
        backup_id: str,
    ) -> shapes.CopyBackupToRegionResponse:
        if _request is None:
            _params = {}
            if destination_region is not autoboto.ShapeBase._NOT_SET:
                _params['destination_region'] = destination_region
            if backup_id is not autoboto.ShapeBase._NOT_SET:
                _params['backup_id'] = backup_id
            _request = shapes.CopyBackupToRegionRequest(**_params)
        response = self._boto_client.copy_backup_to_region(
            **_request.to_boto_dict()
        )

        return shapes.CopyBackupToRegionResponse.from_boto_dict(response)

    def create_cluster(
        self,
        _request: shapes.CreateClusterRequest = None,
        *,
        subnet_ids: typing.List[str],
        hsm_type: str,
        source_backup_id: str = autoboto.ShapeBase._NOT_SET,
    ) -> shapes.CreateClusterResponse:
        """
        Creates a new AWS CloudHSM cluster.
        """
        if _request is None:
            _params = {}
            if subnet_ids is not autoboto.ShapeBase._NOT_SET:
                _params['subnet_ids'] = subnet_ids
            if hsm_type is not autoboto.ShapeBase._NOT_SET:
                _params['hsm_type'] = hsm_type
            if source_backup_id is not autoboto.ShapeBase._NOT_SET:
                _params['source_backup_id'] = source_backup_id
            _request = shapes.CreateClusterRequest(**_params)
        response = self._boto_client.create_cluster(**_request.to_boto_dict())

        return shapes.CreateClusterResponse.from_boto_dict(response)

    def create_hsm(
        self,
        _request: shapes.CreateHsmRequest = None,
        *,
        cluster_id: str,
        availability_zone: str,
        ip_address: str = autoboto.ShapeBase._NOT_SET,
    ) -> shapes.CreateHsmResponse:
        """
        Creates a new hardware security module (HSM) in the specified AWS CloudHSM
        cluster.
        """
        if _request is None:
            _params = {}
            if cluster_id is not autoboto.ShapeBase._NOT_SET:
                _params['cluster_id'] = cluster_id
            if availability_zone is not autoboto.ShapeBase._NOT_SET:
                _params['availability_zone'] = availability_zone
            if ip_address is not autoboto.ShapeBase._NOT_SET:
                _params['ip_address'] = ip_address
            _request = shapes.CreateHsmRequest(**_params)
        response = self._boto_client.create_hsm(**_request.to_boto_dict())

        return shapes.CreateHsmResponse.from_boto_dict(response)

    def delete_cluster(
        self,
        _request: shapes.DeleteClusterRequest = None,
        *,
        cluster_id: str,
    ) -> shapes.DeleteClusterResponse:
        """
        Deletes the specified AWS CloudHSM cluster. Before you can delete a cluster, you
        must delete all HSMs in the cluster. To see if the cluster contains any HSMs,
        use DescribeClusters. To delete an HSM, use DeleteHsm.
        """
        if _request is None:
            _params = {}
            if cluster_id is not autoboto.ShapeBase._NOT_SET:
                _params['cluster_id'] = cluster_id
            _request = shapes.DeleteClusterRequest(**_params)
        response = self._boto_client.delete_cluster(**_request.to_boto_dict())

        return shapes.DeleteClusterResponse.from_boto_dict(response)

    def delete_hsm(
        self,
        _request: shapes.DeleteHsmRequest = None,
        *,
        cluster_id: str,
        hsm_id: str = autoboto.ShapeBase._NOT_SET,
        eni_id: str = autoboto.ShapeBase._NOT_SET,
        eni_ip: str = autoboto.ShapeBase._NOT_SET,
    ) -> shapes.DeleteHsmResponse:
        """
        Deletes the specified HSM. To specify an HSM, you can use its identifier (ID),
        the IP address of the HSM's elastic network interface (ENI), or the ID of the
        HSM's ENI. You need to specify only one of these values. To find these values,
        use DescribeClusters.
        """
        if _request is None:
            _params = {}
            if cluster_id is not autoboto.ShapeBase._NOT_SET:
                _params['cluster_id'] = cluster_id
            if hsm_id is not autoboto.ShapeBase._NOT_SET:
                _params['hsm_id'] = hsm_id
            if eni_id is not autoboto.ShapeBase._NOT_SET:
                _params['eni_id'] = eni_id
            if eni_ip is not autoboto.ShapeBase._NOT_SET:
                _params['eni_ip'] = eni_ip
            _request = shapes.DeleteHsmRequest(**_params)
        response = self._boto_client.delete_hsm(**_request.to_boto_dict())

        return shapes.DeleteHsmResponse.from_boto_dict(response)

    def describe_backups(
        self,
        _request: shapes.DescribeBackupsRequest = None,
        *,
        next_token: str = autoboto.ShapeBase._NOT_SET,
        max_results: int = autoboto.ShapeBase._NOT_SET,
        filters: typing.Dict[str, typing.List[str]
                            ] = autoboto.ShapeBase._NOT_SET,
        sort_ascending: bool = autoboto.ShapeBase._NOT_SET,
    ) -> shapes.DescribeBackupsResponse:
        """
        Gets information about backups of AWS CloudHSM clusters.

        This is a paginated operation, which means that each response might contain only
        a subset of all the backups. When the response contains only a subset of
        backups, it includes a `NextToken` value. Use this value in a subsequent
        `DescribeBackups` request to get more backups. When you receive a response with
        no `NextToken` (or an empty or null value), that means there are no more backups
        to get.
        """
        if _request is None:
            _params = {}
            if next_token is not autoboto.ShapeBase._NOT_SET:
                _params['next_token'] = next_token
            if max_results is not autoboto.ShapeBase._NOT_SET:
                _params['max_results'] = max_results
            if filters is not autoboto.ShapeBase._NOT_SET:
                _params['filters'] = filters
            if sort_ascending is not autoboto.ShapeBase._NOT_SET:
                _params['sort_ascending'] = sort_ascending
            _request = shapes.DescribeBackupsRequest(**_params)
        response = self._boto_client.describe_backups(**_request.to_boto_dict())

        return shapes.DescribeBackupsResponse.from_boto_dict(response)

    def describe_clusters(
        self,
        _request: shapes.DescribeClustersRequest = None,
        *,
        filters: typing.Dict[str, typing.List[str]
                            ] = autoboto.ShapeBase._NOT_SET,
        next_token: str = autoboto.ShapeBase._NOT_SET,
        max_results: int = autoboto.ShapeBase._NOT_SET,
    ) -> shapes.DescribeClustersResponse:
        """
        Gets information about AWS CloudHSM clusters.

        This is a paginated operation, which means that each response might contain only
        a subset of all the clusters. When the response contains only a subset of
        clusters, it includes a `NextToken` value. Use this value in a subsequent
        `DescribeClusters` request to get more clusters. When you receive a response
        with no `NextToken` (or an empty or null value), that means there are no more
        clusters to get.
        """
        if _request is None:
            _params = {}
            if filters is not autoboto.ShapeBase._NOT_SET:
                _params['filters'] = filters
            if next_token is not autoboto.ShapeBase._NOT_SET:
                _params['next_token'] = next_token
            if max_results is not autoboto.ShapeBase._NOT_SET:
                _params['max_results'] = max_results
            _request = shapes.DescribeClustersRequest(**_params)
        response = self._boto_client.describe_clusters(
            **_request.to_boto_dict()
        )

        return shapes.DescribeClustersResponse.from_boto_dict(response)

    def initialize_cluster(
        self,
        _request: shapes.InitializeClusterRequest = None,
        *,
        cluster_id: str,
        signed_cert: str,
        trust_anchor: str,
    ) -> shapes.InitializeClusterResponse:
        """
        Claims an AWS CloudHSM cluster by submitting the cluster certificate issued by
        your issuing certificate authority (CA) and the CA's root certificate. Before
        you can claim a cluster, you must sign the cluster's certificate signing request
        (CSR) with your issuing CA. To get the cluster's CSR, use DescribeClusters.
        """
        if _request is None:
            _params = {}
            if cluster_id is not autoboto.ShapeBase._NOT_SET:
                _params['cluster_id'] = cluster_id
            if signed_cert is not autoboto.ShapeBase._NOT_SET:
                _params['signed_cert'] = signed_cert
            if trust_anchor is not autoboto.ShapeBase._NOT_SET:
                _params['trust_anchor'] = trust_anchor
            _request = shapes.InitializeClusterRequest(**_params)
        response = self._boto_client.initialize_cluster(
            **_request.to_boto_dict()
        )

        return shapes.InitializeClusterResponse.from_boto_dict(response)

    def list_tags(
        self,
        _request: shapes.ListTagsRequest = None,
        *,
        resource_id: str,
        next_token: str = autoboto.ShapeBase._NOT_SET,
        max_results: int = autoboto.ShapeBase._NOT_SET,
    ) -> shapes.ListTagsResponse:
        """
        Gets a list of tags for the specified AWS CloudHSM cluster.

        This is a paginated operation, which means that each response might contain only
        a subset of all the tags. When the response contains only a subset of tags, it
        includes a `NextToken` value. Use this value in a subsequent `ListTags` request
        to get more tags. When you receive a response with no `NextToken` (or an empty
        or null value), that means there are no more tags to get.
        """
        if _request is None:
            _params = {}
            if resource_id is not autoboto.ShapeBase._NOT_SET:
                _params['resource_id'] = resource_id
            if next_token is not autoboto.ShapeBase._NOT_SET:
                _params['next_token'] = next_token
            if max_results is not autoboto.ShapeBase._NOT_SET:
                _params['max_results'] = max_results
            _request = shapes.ListTagsRequest(**_params)
        response = self._boto_client.list_tags(**_request.to_boto_dict())

        return shapes.ListTagsResponse.from_boto_dict(response)

    def tag_resource(
        self,
        _request: shapes.TagResourceRequest = None,
        *,
        resource_id: str,
        tag_list: typing.List[shapes.Tag],
    ) -> shapes.TagResourceResponse:
        """
        Adds or overwrites one or more tags for the specified AWS CloudHSM cluster.
        """
        if _request is None:
            _params = {}
            if resource_id is not autoboto.ShapeBase._NOT_SET:
                _params['resource_id'] = resource_id
            if tag_list is not autoboto.ShapeBase._NOT_SET:
                _params['tag_list'] = tag_list
            _request = shapes.TagResourceRequest(**_params)
        response = self._boto_client.tag_resource(**_request.to_boto_dict())

        return shapes.TagResourceResponse.from_boto_dict(response)

    def untag_resource(
        self,
        _request: shapes.UntagResourceRequest = None,
        *,
        resource_id: str,
        tag_key_list: typing.List[str],
    ) -> shapes.UntagResourceResponse:
        """
        Removes the specified tag or tags from the specified AWS CloudHSM cluster.
        """
        if _request is None:
            _params = {}
            if resource_id is not autoboto.ShapeBase._NOT_SET:
                _params['resource_id'] = resource_id
            if tag_key_list is not autoboto.ShapeBase._NOT_SET:
                _params['tag_key_list'] = tag_key_list
            _request = shapes.UntagResourceRequest(**_params)
        response = self._boto_client.untag_resource(**_request.to_boto_dict())

        return shapes.UntagResourceResponse.from_boto_dict(response)

==> autoboto-0.2.2.tar.gz: autoboto-0.2.2/autoboto/services/cloudhsmv2/client.py <==
import datetime
import typing
import boto3
from autoboto import ShapeBase, OutputShapeBase
from . import shapes


class Client:
    def __init__(self, *args, **kwargs):
        self._boto_client = boto3.client("cloudhsmv2", *args, **kwargs)

    def copy_backup_to_region(
        self,
        _request: shapes.CopyBackupToRegionRequest = None,
        *,
        destination_region: str,
        backup_id: str,
    ) -> shapes.CopyBackupToRegionResponse:
        if _request is None:
            _params = {}
            if destination_region is not ShapeBase.NOT_SET:
                _params['destination_region'] = destination_region
            if backup_id is not ShapeBase.NOT_SET:
                _params['backup_id'] = backup_id
            _request = shapes.CopyBackupToRegionRequest(**_params)
        response = self._boto_client.copy_backup_to_region(
            **_request.to_boto_dict()
        )

        return shapes.CopyBackupToRegionResponse.from_boto_dict(response)

    def create_cluster(
        self,
        _request: shapes.CreateClusterRequest = None,
        *,
        subnet_ids: typing.List[str],
        hsm_type: str,
        source_backup_id: str = ShapeBase.NOT_SET,
    ) -> shapes.CreateClusterResponse:
        """
        Creates a new AWS CloudHSM cluster.
        """
        if _request is None:
            _params = {}
            if subnet_ids is not ShapeBase.NOT_SET:
                _params['subnet_ids'] = subnet_ids
            if hsm_type is not ShapeBase.NOT_SET:
                _params['hsm_type'] = hsm_type
            if source_backup_id is not ShapeBase.NOT_SET:
                _params['source_backup_id'] = source_backup_id
            _request = shapes.CreateClusterRequest(**_params)
        response = self._boto_client.create_cluster(**_request.to_boto_dict())

        return shapes.CreateClusterResponse.from_boto_dict(response)

    def create_hsm(
        self,
        _request: shapes.CreateHsmRequest = None,
        *,
        cluster_id: str,
        availability_zone: str,
        ip_address: str = ShapeBase.NOT_SET,
    ) -> shapes.CreateHsmResponse:
        """
        Creates a new hardware security module (HSM) in the specified AWS CloudHSM
        cluster.
        """
        if _request is None:
            _params = {}
            if cluster_id is not ShapeBase.NOT_SET:
                _params['cluster_id'] = cluster_id
            if availability_zone is not ShapeBase.NOT_SET:
                _params['availability_zone'] = availability_zone
            if ip_address is not ShapeBase.NOT_SET:
                _params['ip_address'] = ip_address
            _request = shapes.CreateHsmRequest(**_params)
        response = self._boto_client.create_hsm(**_request.to_boto_dict())

        return shapes.CreateHsmResponse.from_boto_dict(response)

    def delete_cluster(
        self,
        _request: shapes.DeleteClusterRequest = None,
        *,
        cluster_id: str,
    ) -> shapes.DeleteClusterResponse:
        """
        Deletes the specified AWS CloudHSM cluster. Before you can delete a cluster, you
        must delete all HSMs in the cluster. To see if the cluster contains any HSMs,
        use DescribeClusters. To delete an HSM, use DeleteHsm.
        """
        if _request is None:
            _params = {}
            if cluster_id is not ShapeBase.NOT_SET:
                _params['cluster_id'] = cluster_id
            _request = shapes.DeleteClusterRequest(**_params)
        response = self._boto_client.delete_cluster(**_request.to_boto_dict())

        return shapes.DeleteClusterResponse.from_boto_dict(response)

    def delete_hsm(
        self,
        _request: shapes.DeleteHsmRequest = None,
        *,
        cluster_id: str,
        hsm_id: str = ShapeBase.NOT_SET,
        eni_id: str = ShapeBase.NOT_SET,
        eni_ip: str = ShapeBase.NOT_SET,
    ) -> shapes.DeleteHsmResponse:
        """
        Deletes the specified HSM. To specify an HSM, you can use its identifier (ID),
        the IP address of the HSM's elastic network interface (ENI), or the ID of the
        HSM's ENI. You need to specify only one of these values. To find these values,
        use DescribeClusters.
        """
        if _request is None:
            _params = {}
            if cluster_id is not ShapeBase.NOT_SET:
                _params['cluster_id'] = cluster_id
            if hsm_id is not ShapeBase.NOT_SET:
                _params['hsm_id'] = hsm_id
            if eni_id is not ShapeBase.NOT_SET:
                _params['eni_id'] = eni_id
            if eni_ip is not ShapeBase.NOT_SET:
                _params['eni_ip'] = eni_ip
            _request = shapes.DeleteHsmRequest(**_params)
        response = self._boto_client.delete_hsm(**_request.to_boto_dict())

        return shapes.DeleteHsmResponse.from_boto_dict(response)

    def describe_backups(
        self,
        _request: shapes.DescribeBackupsRequest = None,
        *,
        next_token: str = ShapeBase.NOT_SET,
        max_results: int = ShapeBase.NOT_SET,
        filters: typing.Dict[str, typing.List[str]] = ShapeBase.NOT_SET,
        sort_ascending: bool = ShapeBase.NOT_SET,
    ) -> shapes.DescribeBackupsResponse:
        """
        Gets information about backups of AWS CloudHSM clusters.

        This is a paginated operation, which means that each response might contain only
        a subset of all the backups. When the response contains only a subset of
        backups, it includes a `NextToken` value. Use this value in a subsequent
        `DescribeBackups` request to get more backups. When you receive a response with
        no `NextToken` (or an empty or null value), that means there are no more backups
        to get.
        """
        if _request is None:
            _params = {}
            if next_token is not ShapeBase.NOT_SET:
                _params['next_token'] = next_token
            if max_results is not ShapeBase.NOT_SET:
                _params['max_results'] = max_results
            if filters is not ShapeBase.NOT_SET:
                _params['filters'] = filters
            if sort_ascending is not ShapeBase.NOT_SET:
                _params['sort_ascending'] = sort_ascending
            _request = shapes.DescribeBackupsRequest(**_params)
        response = self._boto_client.describe_backups(**_request.to_boto_dict())

        return shapes.DescribeBackupsResponse.from_boto_dict(response)

    def describe_clusters(
        self,
        _request: shapes.DescribeClustersRequest = None,
        *,
        filters: typing.Dict[str, typing.List[str]] = ShapeBase.NOT_SET,
        next_token: str = ShapeBase.NOT_SET,
        max_results: int = ShapeBase.NOT_SET,
    ) -> shapes.DescribeClustersResponse:
        """
        Gets information about AWS CloudHSM clusters.

        This is a paginated operation, which means that each response might contain only
        a subset of all the clusters. When the response contains only a subset of
        clusters, it includes a `NextToken` value. Use this value in a subsequent
        `DescribeClusters` request to get more clusters. When you receive a response
        with no `NextToken` (or an empty or null value), that means there are no more
        clusters to get.
        """
        if _request is None:
            _params = {}
            if filters is not ShapeBase.NOT_SET:
                _params['filters'] = filters
            if next_token is not ShapeBase.NOT_SET:
                _params['next_token'] = next_token
            if max_results is not ShapeBase.NOT_SET:
                _params['max_results'] = max_results
            _request = shapes.DescribeClustersRequest(**_params)
        response = self._boto_client.describe_clusters(
            **_request.to_boto_dict()
        )

        return shapes.DescribeClustersResponse.from_boto_dict(response)

    def initialize_cluster(
        self,
        _request: shapes.InitializeClusterRequest = None,
        *,
        cluster_id: str,
        signed_cert: str,
        trust_anchor: str,
    ) -> shapes.InitializeClusterResponse:
        """
        Claims an AWS CloudHSM cluster by submitting the cluster certificate issued by
        your issuing certificate authority (CA) and the CA's root certificate. Before
        you can claim a cluster, you must sign the cluster's certificate signing request
        (CSR) with your issuing CA. To get the cluster's CSR, use DescribeClusters.
        """
        if _request is None:
            _params = {}
            if cluster_id is not ShapeBase.NOT_SET:
                _params['cluster_id'] = cluster_id
            if signed_cert is not ShapeBase.NOT_SET:
                _params['signed_cert'] = signed_cert
            if trust_anchor is not ShapeBase.NOT_SET:
                _params['trust_anchor'] = trust_anchor
            _request = shapes.InitializeClusterRequest(**_params)
        response = self._boto_client.initialize_cluster(
            **_request.to_boto_dict()
        )

        return shapes.InitializeClusterResponse.from_boto_dict(response)

    def list_tags(
        self,
        _request: shapes.ListTagsRequest = None,
        *,
        resource_id: str,
        next_token: str = ShapeBase.NOT_SET,
        max_results: int = ShapeBase.NOT_SET,
    ) -> shapes.ListTagsResponse:
        """
        Gets a list of tags for the specified AWS CloudHSM cluster.

        This is a paginated operation, which means that each response might contain only
        a subset of all the tags. When the response contains only a subset of tags, it
        includes a `NextToken` value. Use this value in a subsequent `ListTags` request
        to get more tags. When you receive a response with no `NextToken` (or an empty
        or null value), that means there are no more tags to get.
        """
        if _request is None:
            _params = {}
            if resource_id is not ShapeBase.NOT_SET:
                _params['resource_id'] = resource_id
            if next_token is not ShapeBase.NOT_SET:
                _params['next_token'] = next_token
            if max_results is not ShapeBase.NOT_SET:
                _params['max_results'] = max_results
            _request = shapes.ListTagsRequest(**_params)
        response = self._boto_client.list_tags(**_request.to_boto_dict())

        return shapes.ListTagsResponse.from_boto_dict(response)

    def tag_resource(
        self,
        _request: shapes.TagResourceRequest = None,
        *,
        resource_id: str,
        tag_list: typing.List[shapes.Tag],
    ) -> shapes.TagResourceResponse:
        """
        Adds or overwrites one or more tags for the specified AWS CloudHSM cluster.
        """
        if _request is None:
            _params = {}
            if resource_id is not ShapeBase.NOT_SET:
                _params['resource_id'] = resource_id
            if tag_list is not ShapeBase.NOT_SET:
                _params['tag_list'] = tag_list
            _request = shapes.TagResourceRequest(**_params)
        response = self._boto_client.tag_resource(**_request.to_boto_dict())

        return shapes.TagResourceResponse.from_boto_dict(response)

    def untag_resource(
        self,
        _request: shapes.UntagResourceRequest = None,
        *,
        resource_id: str,
        tag_key_list: typing.List[str],
    ) -> shapes.UntagResourceResponse:
        """
        Removes the specified tag or tags from the specified AWS CloudHSM cluster.
        """
        if _request is None:
            _params = {}
            if resource_id is not ShapeBase.NOT_SET:
                _params['resource_id'] = resource_id
            if tag_key_list is not ShapeBase.NOT_SET:
                _params['tag_key_list'] = tag_key_list
            _request = shapes.UntagResourceRequest(**_params)
        response = self._boto_client.untag_resource(**_request.to_boto_dict())

        return shapes.UntagResourceResponse.from_boto_dict(response)
